@@ -1,4 +1,4 @@
-from grai_schemas.v1.metadata import edges, metadata, nodes
+from grai_schemas.v1.metadata import edges, generics, metadata, nodes
 from grai_schemas.v1.metadata.edges import Metadata as GraiEdgeMetadataV1
 from grai_schemas.v1.metadata.metadata import GraiMetadataV1
 from grai_schemas.v1.metadata.nodes import Metadata as GraiNodeMetadataV1
